@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,15 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Callable, Dict, Optional, Sequence, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import grpc_helpers  # type: ignore
 from google.api_core import operations_v1  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
@@ -34,8 +32,7 @@ from google.cloud.automl_v1.types import model
 from google.cloud.automl_v1.types import model as gca_model
 from google.cloud.automl_v1.types import model_evaluation
 from google.cloud.automl_v1.types import service
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import AutoMlTransport, DEFAULT_CLIENT_INFO
 
 
@@ -72,7 +69,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
         self,
         *,
         host: str = "automl.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
@@ -82,11 +79,13 @@ class AutoMlGrpcTransport(AutoMlTransport):
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -121,6 +120,8 @@ class AutoMlGrpcTransport(AutoMlTransport):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
 
         Raises:
           google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
@@ -174,6 +175,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
             scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
 
         if not self._grpc_channel:
@@ -197,7 +199,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
     def create_channel(
         cls,
         host: str = "automl.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -228,13 +230,15 @@ class AutoMlGrpcTransport(AutoMlTransport):
             google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            default_scopes=cls.AUTH_SCOPES,
+            scopes=scopes,
+            default_host=cls.DEFAULT_HOST,
             **kwargs,
         )
 
@@ -261,7 +265,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
     @property
     def create_dataset(
         self,
-    ) -> Callable[[service.CreateDatasetRequest], operations.Operation]:
+    ) -> Callable[[service.CreateDatasetRequest], operations_pb2.Operation]:
         r"""Return a callable for the create dataset method over gRPC.
 
         Creates a dataset.
@@ -280,7 +284,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
             self._stubs["create_dataset"] = self.grpc_channel.unary_unary(
                 "/google.cloud.automl.v1.AutoMl/CreateDataset",
                 request_serializer=service.CreateDatasetRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_dataset"]
 
@@ -363,7 +367,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
     @property
     def delete_dataset(
         self,
-    ) -> Callable[[service.DeleteDatasetRequest], operations.Operation]:
+    ) -> Callable[[service.DeleteDatasetRequest], operations_pb2.Operation]:
         r"""Return a callable for the delete dataset method over gRPC.
 
         Deletes a dataset and all of its contents. Returns empty
@@ -386,14 +390,14 @@ class AutoMlGrpcTransport(AutoMlTransport):
             self._stubs["delete_dataset"] = self.grpc_channel.unary_unary(
                 "/google.cloud.automl.v1.AutoMl/DeleteDataset",
                 request_serializer=service.DeleteDatasetRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_dataset"]
 
     @property
     def import_data(
         self,
-    ) -> Callable[[service.ImportDataRequest], operations.Operation]:
+    ) -> Callable[[service.ImportDataRequest], operations_pb2.Operation]:
         r"""Return a callable for the import data method over gRPC.
 
         Imports data into a dataset. For Tables this method can only be
@@ -421,14 +425,14 @@ class AutoMlGrpcTransport(AutoMlTransport):
             self._stubs["import_data"] = self.grpc_channel.unary_unary(
                 "/google.cloud.automl.v1.AutoMl/ImportData",
                 request_serializer=service.ImportDataRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["import_data"]
 
     @property
     def export_data(
         self,
-    ) -> Callable[[service.ExportDataRequest], operations.Operation]:
+    ) -> Callable[[service.ExportDataRequest], operations_pb2.Operation]:
         r"""Return a callable for the export data method over gRPC.
 
         Exports dataset's data to the provided output location. Returns
@@ -450,7 +454,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
             self._stubs["export_data"] = self.grpc_channel.unary_unary(
                 "/google.cloud.automl.v1.AutoMl/ExportData",
                 request_serializer=service.ExportDataRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["export_data"]
 
@@ -483,7 +487,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
     @property
     def create_model(
         self,
-    ) -> Callable[[service.CreateModelRequest], operations.Operation]:
+    ) -> Callable[[service.CreateModelRequest], operations_pb2.Operation]:
         r"""Return a callable for the create model method over gRPC.
 
         Creates a model. Returns a Model in the
@@ -506,7 +510,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
             self._stubs["create_model"] = self.grpc_channel.unary_unary(
                 "/google.cloud.automl.v1.AutoMl/CreateModel",
                 request_serializer=service.CreateModelRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_model"]
 
@@ -563,7 +567,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
     @property
     def delete_model(
         self,
-    ) -> Callable[[service.DeleteModelRequest], operations.Operation]:
+    ) -> Callable[[service.DeleteModelRequest], operations_pb2.Operation]:
         r"""Return a callable for the delete model method over gRPC.
 
         Deletes a model. Returns ``google.protobuf.Empty`` in the
@@ -585,7 +589,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
             self._stubs["delete_model"] = self.grpc_channel.unary_unary(
                 "/google.cloud.automl.v1.AutoMl/DeleteModel",
                 request_serializer=service.DeleteModelRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_model"]
 
@@ -616,7 +620,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
     @property
     def deploy_model(
         self,
-    ) -> Callable[[service.DeployModelRequest], operations.Operation]:
+    ) -> Callable[[service.DeployModelRequest], operations_pb2.Operation]:
         r"""Return a callable for the deploy model method over gRPC.
 
         Deploys a model. If a model is already deployed, deploying it
@@ -649,14 +653,14 @@ class AutoMlGrpcTransport(AutoMlTransport):
             self._stubs["deploy_model"] = self.grpc_channel.unary_unary(
                 "/google.cloud.automl.v1.AutoMl/DeployModel",
                 request_serializer=service.DeployModelRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["deploy_model"]
 
     @property
     def undeploy_model(
         self,
-    ) -> Callable[[service.UndeployModelRequest], operations.Operation]:
+    ) -> Callable[[service.UndeployModelRequest], operations_pb2.Operation]:
         r"""Return a callable for the undeploy model method over gRPC.
 
         Undeploys a model. If the model is not deployed this method has
@@ -683,14 +687,14 @@ class AutoMlGrpcTransport(AutoMlTransport):
             self._stubs["undeploy_model"] = self.grpc_channel.unary_unary(
                 "/google.cloud.automl.v1.AutoMl/UndeployModel",
                 request_serializer=service.UndeployModelRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["undeploy_model"]
 
     @property
     def export_model(
         self,
-    ) -> Callable[[service.ExportModelRequest], operations.Operation]:
+    ) -> Callable[[service.ExportModelRequest], operations_pb2.Operation]:
         r"""Return a callable for the export model method over gRPC.
 
         Exports a trained, "export-able", model to a user specified
@@ -716,7 +720,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
             self._stubs["export_model"] = self.grpc_channel.unary_unary(
                 "/google.cloud.automl.v1.AutoMl/ExportModel",
                 request_serializer=service.ExportModelRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["export_model"]
 
