@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,10 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.automl_v1.types import geometry
 
 
@@ -33,7 +30,6 @@ __protobuf__ = proto.module(
 
 class ImageObjectDetectionAnnotation(proto.Message):
     r"""Annotation details for image object detection.
-
     Attributes:
         bounding_box (google.cloud.automl_v1.types.BoundingPoly):
             Output only. The rectangle representing the
@@ -45,8 +41,7 @@ class ImageObjectDetectionAnnotation(proto.Message):
     """
 
     bounding_box = proto.Field(proto.MESSAGE, number=1, message=geometry.BoundingPoly,)
-
-    score = proto.Field(proto.FLOAT, number=2)
+    score = proto.Field(proto.FLOAT, number=2,)
 
 
 class BoundingBoxMetricsEntry(proto.Message):
@@ -71,7 +66,6 @@ class BoundingBoxMetricsEntry(proto.Message):
 
     class ConfidenceMetricsEntry(proto.Message):
         r"""Metrics for a single confidence threshold.
-
         Attributes:
             confidence_threshold (float):
                 Output only. The confidence threshold value
@@ -87,18 +81,13 @@ class BoundingBoxMetricsEntry(proto.Message):
                 precision.
         """
 
-        confidence_threshold = proto.Field(proto.FLOAT, number=1)
-
-        recall = proto.Field(proto.FLOAT, number=2)
-
-        precision = proto.Field(proto.FLOAT, number=3)
-
-        f1_score = proto.Field(proto.FLOAT, number=4)
-
-    iou_threshold = proto.Field(proto.FLOAT, number=1)
-
-    mean_average_precision = proto.Field(proto.FLOAT, number=2)
+        confidence_threshold = proto.Field(proto.FLOAT, number=1,)
+        recall = proto.Field(proto.FLOAT, number=2,)
+        precision = proto.Field(proto.FLOAT, number=3,)
+        f1_score = proto.Field(proto.FLOAT, number=4,)
 
+    iou_threshold = proto.Field(proto.FLOAT, number=1,)
+    mean_average_precision = proto.Field(proto.FLOAT, number=2,)
     confidence_metrics_entries = proto.RepeatedField(
         proto.MESSAGE, number=3, message=ConfidenceMetricsEntry,
     )
@@ -125,13 +114,11 @@ class ImageObjectDetectionEvaluationMetrics(proto.Message):
             bounding_box_metrics_entries.
     """
 
-    evaluated_bounding_box_count = proto.Field(proto.INT32, number=1)
-
+    evaluated_bounding_box_count = proto.Field(proto.INT32, number=1,)
     bounding_box_metrics_entries = proto.RepeatedField(
         proto.MESSAGE, number=2, message="BoundingBoxMetricsEntry",
     )
-
-    bounding_box_mean_average_precision = proto.Field(proto.FLOAT, number=3)
+    bounding_box_mean_average_precision = proto.Field(proto.FLOAT, number=3,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
