@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,10 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.automl_v1.types import annotation_payload
 from google.cloud.automl_v1.types import data_items
 from google.cloud.automl_v1.types import io
@@ -78,11 +75,9 @@ class PredictRequest(proto.Message):
             objects. The default is false.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     payload = proto.Field(proto.MESSAGE, number=2, message=data_items.ExamplePayload,)
-
-    params = proto.MapField(proto.STRING, proto.STRING, number=3)
+    params = proto.MapField(proto.STRING, proto.STRING, number=3,)
 
 
 class PredictResponse(proto.Message):
@@ -128,12 +123,10 @@ class PredictResponse(proto.Message):
     payload = proto.RepeatedField(
         proto.MESSAGE, number=1, message=annotation_payload.AnnotationPayload,
     )
-
     preprocessed_input = proto.Field(
         proto.MESSAGE, number=3, message=data_items.ExamplePayload,
     )
-
-    metadata = proto.MapField(proto.STRING, proto.STRING, number=2)
+    metadata = proto.MapField(proto.STRING, proto.STRING, number=2,)
 
 
 class BatchPredictRequest(proto.Message):
@@ -235,17 +228,14 @@ class BatchPredictRequest(proto.Message):
             Default is 0.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     input_config = proto.Field(
         proto.MESSAGE, number=3, message=io.BatchPredictInputConfig,
     )
-
     output_config = proto.Field(
         proto.MESSAGE, number=4, message=io.BatchPredictOutputConfig,
     )
-
-    params = proto.MapField(proto.STRING, proto.STRING, number=5)
+    params = proto.MapField(proto.STRING, proto.STRING, number=5,)
 
 
 class BatchPredictResult(proto.Message):
@@ -269,7 +259,7 @@ class BatchPredictResult(proto.Message):
             bounding boxes returned per frame.
     """
 
-    metadata = proto.MapField(proto.STRING, proto.STRING, number=1)
+    metadata = proto.MapField(proto.STRING, proto.STRING, number=1,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
