@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,17 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import abc
-import typing
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
+import packaging.version
 import pkg_resources
 
-from google import auth  # type: ignore
-from google.api_core import exceptions  # type: ignore
+import google.auth  # type: ignore
+import google.api_core  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.api_core import operations_v1  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
+from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.automl_v1beta1.types import annotation_spec
 from google.cloud.automl_v1beta1.types import column_spec
@@ -36,8 +37,7 @@ from google.cloud.automl_v1beta1.types import model_evaluation
 from google.cloud.automl_v1beta1.types import service
 from google.cloud.automl_v1beta1.types import table_spec
 from google.cloud.automl_v1beta1.types import table_spec as gca_table_spec
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -46,27 +46,40 @@ try:
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
+try:
+    # google.auth.__version__ was added in 1.26.0
+    _GOOGLE_AUTH_VERSION = google.auth.__version__
+except AttributeError:
+    try:  # try pkg_resources if it is available
+        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
+    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
+        _GOOGLE_AUTH_VERSION = None
+
 
 class AutoMlTransport(abc.ABC):
     """Abstract transport class for AutoMl."""
 
     AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)
 
+    DEFAULT_HOST: str = "automl.googleapis.com"
+
     def __init__(
         self,
         *,
-        host: str = "automl.googleapis.com",
-        credentials: credentials.Credentials = None,
-        credentials_file: typing.Optional[str] = None,
-        scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
-        quota_project_id: typing.Optional[str] = None,
+        host: str = DEFAULT_HOST,
+        credentials: ga_credentials.Credentials = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -75,7 +88,7 @@ class AutoMlTransport(abc.ABC):
             credentials_file (Optional[str]): A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
                 This argument is mutually exclusive with credentials.
-            scope (Optional[Sequence[str]]): A list of scopes.
+            scopes (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
             client_info (google.api_core.gapic_v1.client_info.ClientInfo):
@@ -83,35 +96,70 @@ class AutoMlTransport(abc.ABC):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
         self._host = host
 
+        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)
+
         # Save the scopes.
-        self._scopes = scopes or self.AUTH_SCOPES
+        self._scopes = scopes
 
         # If no credentials are provided, then determine the appropriate
         # defaults.
         if credentials and credentials_file:
-            raise exceptions.DuplicateCredentialArgs(
+            raise core_exceptions.DuplicateCredentialArgs(
                 "'credentials_file' and 'credentials' are mutually exclusive"
             )
 
         if credentials_file is not None:
-            credentials, _ = auth.load_credentials_from_file(
-                credentials_file, scopes=self._scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.load_credentials_from_file(
+                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
 
         elif credentials is None:
-            credentials, _ = auth.default(
-                scopes=self._scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.default(
+                **scopes_kwargs, quota_project_id=quota_project_id
             )
 
+        # If the credentials is service account credentials, then always try to use self signed JWT.
+        if (
+            always_use_jwt_access
+            and isinstance(credentials, service_account.Credentials)
+            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
+        ):
+            credentials = credentials.with_always_use_jwt_access(True)
+
         # Save the credentials.
         self._credentials = credentials
 
+    # TODO(busunkim): This method is in the base transport
+    # to avoid duplicating code across the transport classes. These functions
+    # should be deleted once the minimum required versions of google-auth is increased.
+
+    # TODO: Remove this function once google-auth >= 1.25.0 is required
+    @classmethod
+    def _get_scopes_kwargs(
+        cls, host: str, scopes: Optional[Sequence[str]]
+    ) -> Dict[str, Optional[Sequence[str]]]:
+        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""
+
+        scopes_kwargs = {}
+
+        if _GOOGLE_AUTH_VERSION and (
+            packaging.version.parse(_GOOGLE_AUTH_VERSION)
+            >= packaging.version.parse("1.25.0")
+        ):
+            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
+        else:
+            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}
+
+        return scopes_kwargs
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -125,7 +173,8 @@ class AutoMlTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=5.0,
                 ),
@@ -139,7 +188,8 @@ class AutoMlTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=5.0,
                 ),
@@ -156,7 +206,8 @@ class AutoMlTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=5.0,
                 ),
@@ -176,7 +227,8 @@ class AutoMlTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=5.0,
                 ),
@@ -190,7 +242,8 @@ class AutoMlTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=5.0,
                 ),
@@ -204,7 +257,8 @@ class AutoMlTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=5.0,
                 ),
@@ -221,7 +275,8 @@ class AutoMlTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=5.0,
                 ),
@@ -235,7 +290,8 @@ class AutoMlTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=5.0,
                 ),
@@ -255,7 +311,8 @@ class AutoMlTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=5.0,
                 ),
@@ -269,7 +326,8 @@ class AutoMlTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=5.0,
                 ),
@@ -283,7 +341,8 @@ class AutoMlTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=5.0,
                 ),
@@ -311,7 +370,8 @@ class AutoMlTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=5.0,
                 ),
@@ -333,76 +393,72 @@ class AutoMlTransport(abc.ABC):
     @property
     def create_dataset(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.CreateDatasetRequest],
-        typing.Union[gca_dataset.Dataset, typing.Awaitable[gca_dataset.Dataset]],
+        Union[gca_dataset.Dataset, Awaitable[gca_dataset.Dataset]],
     ]:
         raise NotImplementedError()
 
     @property
     def get_dataset(
         self,
-    ) -> typing.Callable[
-        [service.GetDatasetRequest],
-        typing.Union[dataset.Dataset, typing.Awaitable[dataset.Dataset]],
+    ) -> Callable[
+        [service.GetDatasetRequest], Union[dataset.Dataset, Awaitable[dataset.Dataset]]
     ]:
         raise NotImplementedError()
 
     @property
     def list_datasets(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.ListDatasetsRequest],
-        typing.Union[
-            service.ListDatasetsResponse, typing.Awaitable[service.ListDatasetsResponse]
-        ],
+        Union[service.ListDatasetsResponse, Awaitable[service.ListDatasetsResponse]],
     ]:
         raise NotImplementedError()
 
     @property
     def update_dataset(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.UpdateDatasetRequest],
-        typing.Union[gca_dataset.Dataset, typing.Awaitable[gca_dataset.Dataset]],
+        Union[gca_dataset.Dataset, Awaitable[gca_dataset.Dataset]],
     ]:
         raise NotImplementedError()
 
     @property
     def delete_dataset(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.DeleteDatasetRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def import_data(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.ImportDataRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def export_data(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.ExportDataRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def get_annotation_spec(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.GetAnnotationSpecRequest],
-        typing.Union[
-            annotation_spec.AnnotationSpec,
-            typing.Awaitable[annotation_spec.AnnotationSpec],
+        Union[
+            annotation_spec.AnnotationSpec, Awaitable[annotation_spec.AnnotationSpec]
         ],
     ]:
         raise NotImplementedError()
@@ -410,20 +466,19 @@ class AutoMlTransport(abc.ABC):
     @property
     def get_table_spec(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.GetTableSpecRequest],
-        typing.Union[table_spec.TableSpec, typing.Awaitable[table_spec.TableSpec]],
+        Union[table_spec.TableSpec, Awaitable[table_spec.TableSpec]],
     ]:
         raise NotImplementedError()
 
     @property
     def list_table_specs(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.ListTableSpecsRequest],
-        typing.Union[
-            service.ListTableSpecsResponse,
-            typing.Awaitable[service.ListTableSpecsResponse],
+        Union[
+            service.ListTableSpecsResponse, Awaitable[service.ListTableSpecsResponse]
         ],
     ]:
         raise NotImplementedError()
@@ -431,31 +486,28 @@ class AutoMlTransport(abc.ABC):
     @property
     def update_table_spec(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.UpdateTableSpecRequest],
-        typing.Union[
-            gca_table_spec.TableSpec, typing.Awaitable[gca_table_spec.TableSpec]
-        ],
+        Union[gca_table_spec.TableSpec, Awaitable[gca_table_spec.TableSpec]],
     ]:
         raise NotImplementedError()
 
     @property
     def get_column_spec(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.GetColumnSpecRequest],
-        typing.Union[column_spec.ColumnSpec, typing.Awaitable[column_spec.ColumnSpec]],
+        Union[column_spec.ColumnSpec, Awaitable[column_spec.ColumnSpec]],
     ]:
         raise NotImplementedError()
 
     @property
     def list_column_specs(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.ListColumnSpecsRequest],
-        typing.Union[
-            service.ListColumnSpecsResponse,
-            typing.Awaitable[service.ListColumnSpecsResponse],
+        Union[
+            service.ListColumnSpecsResponse, Awaitable[service.ListColumnSpecsResponse]
         ],
     ]:
         raise NotImplementedError()
@@ -463,96 +515,91 @@ class AutoMlTransport(abc.ABC):
     @property
     def update_column_spec(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.UpdateColumnSpecRequest],
-        typing.Union[
-            gca_column_spec.ColumnSpec, typing.Awaitable[gca_column_spec.ColumnSpec]
-        ],
+        Union[gca_column_spec.ColumnSpec, Awaitable[gca_column_spec.ColumnSpec]],
     ]:
         raise NotImplementedError()
 
     @property
     def create_model(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.CreateModelRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def get_model(
         self,
-    ) -> typing.Callable[
-        [service.GetModelRequest],
-        typing.Union[model.Model, typing.Awaitable[model.Model]],
+    ) -> Callable[
+        [service.GetModelRequest], Union[model.Model, Awaitable[model.Model]]
     ]:
         raise NotImplementedError()
 
     @property
     def list_models(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.ListModelsRequest],
-        typing.Union[
-            service.ListModelsResponse, typing.Awaitable[service.ListModelsResponse]
-        ],
+        Union[service.ListModelsResponse, Awaitable[service.ListModelsResponse]],
     ]:
         raise NotImplementedError()
 
     @property
     def delete_model(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.DeleteModelRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def deploy_model(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.DeployModelRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def undeploy_model(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.UndeployModelRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def export_model(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.ExportModelRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def export_evaluated_examples(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.ExportEvaluatedExamplesRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def get_model_evaluation(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.GetModelEvaluationRequest],
-        typing.Union[
+        Union[
             model_evaluation.ModelEvaluation,
-            typing.Awaitable[model_evaluation.ModelEvaluation],
+            Awaitable[model_evaluation.ModelEvaluation],
         ],
     ]:
         raise NotImplementedError()
@@ -560,11 +607,11 @@ class AutoMlTransport(abc.ABC):
     @property
     def list_model_evaluations(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [service.ListModelEvaluationsRequest],
-        typing.Union[
+        Union[
             service.ListModelEvaluationsResponse,
-            typing.Awaitable[service.ListModelEvaluationsResponse],
+            Awaitable[service.ListModelEvaluationsResponse],
         ],
     ]:
         raise NotImplementedError()
