@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,10 +20,10 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation  # type: ignore
@@ -35,7 +33,6 @@ from google.cloud.automl_v1beta1.types import data_items
 from google.cloud.automl_v1beta1.types import io
 from google.cloud.automl_v1beta1.types import operations
 from google.cloud.automl_v1beta1.types import prediction_service
-
 from .transports.base import PredictionServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import PredictionServiceGrpcAsyncIOTransport
 from .client import PredictionServiceClient
@@ -55,31 +52,26 @@ class PredictionServiceAsyncClient:
 
     model_path = staticmethod(PredictionServiceClient.model_path)
     parse_model_path = staticmethod(PredictionServiceClient.parse_model_path)
-
     common_billing_account_path = staticmethod(
         PredictionServiceClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         PredictionServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(PredictionServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         PredictionServiceClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         PredictionServiceClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         PredictionServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(PredictionServiceClient.common_project_path)
     parse_common_project_path = staticmethod(
         PredictionServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(PredictionServiceClient.common_location_path)
     parse_common_location_path = staticmethod(
         PredictionServiceClient.parse_common_location_path
@@ -87,7 +79,8 @@ class PredictionServiceAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -102,7 +95,7 @@ class PredictionServiceAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -119,7 +112,7 @@ class PredictionServiceAsyncClient:
 
     @property
     def transport(self) -> PredictionServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             PredictionServiceTransport: The transport used by the client instance.
@@ -133,12 +126,12 @@ class PredictionServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, PredictionServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the prediction service client.
+        """Instantiates the prediction service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -170,7 +163,6 @@ class PredictionServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = PredictionServiceClient(
             credentials=credentials,
             transport=transport,
@@ -258,7 +250,6 @@ class PredictionServiceAsyncClient:
                 This corresponds to the ``params`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -285,7 +276,6 @@ class PredictionServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
         if payload is not None:
@@ -458,7 +448,6 @@ class PredictionServiceAsyncClient:
                 This corresponds to the ``params`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -489,7 +478,6 @@ class PredictionServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
         if input_config is not None:
