@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -61,37 +59,28 @@ class DataStats(proto.Message):
     float64_stats = proto.Field(
         proto.MESSAGE, number=3, oneof="stats", message="Float64Stats",
     )
-
     string_stats = proto.Field(
         proto.MESSAGE, number=4, oneof="stats", message="StringStats",
     )
-
     timestamp_stats = proto.Field(
         proto.MESSAGE, number=5, oneof="stats", message="TimestampStats",
     )
-
     array_stats = proto.Field(
         proto.MESSAGE, number=6, oneof="stats", message="ArrayStats",
     )
-
     struct_stats = proto.Field(
         proto.MESSAGE, number=7, oneof="stats", message="StructStats",
     )
-
     category_stats = proto.Field(
         proto.MESSAGE, number=8, oneof="stats", message="CategoryStats",
     )
-
-    distinct_value_count = proto.Field(proto.INT64, number=1)
-
-    null_value_count = proto.Field(proto.INT64, number=2)
-
-    valid_value_count = proto.Field(proto.INT64, number=9)
+    distinct_value_count = proto.Field(proto.INT64, number=1,)
+    null_value_count = proto.Field(proto.INT64, number=2,)
+    valid_value_count = proto.Field(proto.INT64, number=9,)
 
 
 class Float64Stats(proto.Message):
     r"""The data statistics of a series of FLOAT64 values.
-
     Attributes:
         mean (float):
             The mean of the series.
@@ -113,7 +102,6 @@ class Float64Stats(proto.Message):
 
     class HistogramBucket(proto.Message):
         r"""A bucket of a histogram.
-
         Attributes:
             min_ (float):
                 The minimum value of the bucket, inclusive.
@@ -125,18 +113,13 @@ class Float64Stats(proto.Message):
                 bucket, i.e. are between min and max values.
         """
 
-        min_ = proto.Field(proto.DOUBLE, number=1)
-
-        max_ = proto.Field(proto.DOUBLE, number=2)
-
-        count = proto.Field(proto.INT64, number=3)
-
-    mean = proto.Field(proto.DOUBLE, number=1)
-
-    standard_deviation = proto.Field(proto.DOUBLE, number=2)
-
-    quantiles = proto.RepeatedField(proto.DOUBLE, number=3)
+        min_ = proto.Field(proto.DOUBLE, number=1,)
+        max_ = proto.Field(proto.DOUBLE, number=2,)
+        count = proto.Field(proto.INT64, number=3,)
 
+    mean = proto.Field(proto.DOUBLE, number=1,)
+    standard_deviation = proto.Field(proto.DOUBLE, number=2,)
+    quantiles = proto.RepeatedField(proto.DOUBLE, number=3,)
     histogram_buckets = proto.RepeatedField(
         proto.MESSAGE, number=4, message=HistogramBucket,
     )
@@ -144,7 +127,6 @@ class Float64Stats(proto.Message):
 
 class StringStats(proto.Message):
     r"""The data statistics of a series of STRING values.
-
     Attributes:
         top_unigram_stats (Sequence[google.cloud.automl_v1beta1.types.StringStats.UnigramStats]):
             The statistics of the top 20 unigrams, ordered by
@@ -153,7 +135,6 @@ class StringStats(proto.Message):
 
     class UnigramStats(proto.Message):
         r"""The statistics of a unigram.
-
         Attributes:
             value (str):
                 The unigram.
@@ -162,9 +143,8 @@ class StringStats(proto.Message):
                 the series.
         """
 
-        value = proto.Field(proto.STRING, number=1)
-
-        count = proto.Field(proto.INT64, number=2)
+        value = proto.Field(proto.STRING, number=1,)
+        count = proto.Field(proto.INT64, number=2,)
 
     top_unigram_stats = proto.RepeatedField(
         proto.MESSAGE, number=1, message=UnigramStats,
@@ -173,7 +153,6 @@ class StringStats(proto.Message):
 
 class TimestampStats(proto.Message):
     r"""The data statistics of a series of TIMESTAMP values.
-
     Attributes:
         granular_stats (Sequence[google.cloud.automl_v1beta1.types.TimestampStats.GranularStatsEntry]):
             The string key is the pre-defined granularity. Currently
@@ -185,7 +164,6 @@ class TimestampStats(proto.Message):
 
     class GranularStats(proto.Message):
         r"""Stats split by a defined in context granularity.
-
         Attributes:
             buckets (Sequence[google.cloud.automl_v1beta1.types.TimestampStats.GranularStats.BucketsEntry]):
                 A map from granularity key to example count for that key.
@@ -193,7 +171,7 @@ class TimestampStats(proto.Message):
                 ``5`` means May).
         """
 
-        buckets = proto.MapField(proto.INT32, proto.INT64, number=1)
+        buckets = proto.MapField(proto.INT32, proto.INT64, number=1,)
 
     granular_stats = proto.MapField(
         proto.STRING, proto.MESSAGE, number=1, message=GranularStats,
@@ -202,7 +180,6 @@ class TimestampStats(proto.Message):
 
 class ArrayStats(proto.Message):
     r"""The data statistics of a series of ARRAY values.
-
     Attributes:
         member_stats (google.cloud.automl_v1beta1.types.DataStats):
             Stats of all the values of all arrays, as if
@@ -215,7 +192,6 @@ class ArrayStats(proto.Message):
 
 class StructStats(proto.Message):
     r"""The data statistics of a series of STRUCT values.
-
     Attributes:
         field_stats (Sequence[google.cloud.automl_v1beta1.types.StructStats.FieldStatsEntry]):
             Map from a field name of the struct to data
@@ -230,7 +206,6 @@ class StructStats(proto.Message):
 
 class CategoryStats(proto.Message):
     r"""The data statistics of a series of CATEGORY values.
-
     Attributes:
         top_category_stats (Sequence[google.cloud.automl_v1beta1.types.CategoryStats.SingleCategoryStats]):
             The statistics of the top 20 CATEGORY values, ordered by
@@ -240,7 +215,6 @@ class CategoryStats(proto.Message):
 
     class SingleCategoryStats(proto.Message):
         r"""The statistics of a single CATEGORY value.
-
         Attributes:
             value (str):
                 The CATEGORY value.
@@ -249,9 +223,8 @@ class CategoryStats(proto.Message):
                 the series.
         """
 
-        value = proto.Field(proto.STRING, number=1)
-
-        count = proto.Field(proto.INT64, number=2)
+        value = proto.Field(proto.STRING, number=1,)
+        count = proto.Field(proto.INT64, number=2,)
 
     top_category_stats = proto.RepeatedField(
         proto.MESSAGE, number=1, message=SingleCategoryStats,
@@ -269,7 +242,7 @@ class CorrelationStats(proto.Message):
             measure.
     """
 
-    cramers_v = proto.Field(proto.DOUBLE, number=1)
+    cramers_v = proto.Field(proto.DOUBLE, number=1,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
