@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -359,12 +357,10 @@ class InputConfig(proto.Message):
     gcs_source = proto.Field(
         proto.MESSAGE, number=1, oneof="source", message="GcsSource",
     )
-
     bigquery_source = proto.Field(
         proto.MESSAGE, number=3, oneof="source", message="BigQuerySource",
     )
-
-    params = proto.MapField(proto.STRING, proto.STRING, number=2)
+    params = proto.MapField(proto.STRING, proto.STRING, number=2,)
 
 
 class BatchPredictInputConfig(proto.Message):
@@ -531,7 +527,6 @@ class BatchPredictInputConfig(proto.Message):
     gcs_source = proto.Field(
         proto.MESSAGE, number=1, oneof="source", message="GcsSource",
     )
-
     bigquery_source = proto.Field(
         proto.MESSAGE, number=2, oneof="source", message="BigQuerySource",
     )
@@ -595,7 +590,6 @@ class OutputConfig(proto.Message):
     gcs_destination = proto.Field(
         proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
     )
-
     bigquery_destination = proto.Field(
         proto.MESSAGE, number=2, oneof="destination", message="BigQueryDestination",
     )
@@ -901,7 +895,6 @@ class BatchPredictOutputConfig(proto.Message):
     gcs_destination = proto.Field(
         proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
     )
-
     bigquery_destination = proto.Field(
         proto.MESSAGE, number=2, oneof="destination", message="BigQueryDestination",
     )
@@ -909,7 +902,6 @@ class BatchPredictOutputConfig(proto.Message):
 
 class ModelExportOutputConfig(proto.Message):
     r"""Output configuration for ModelExport Action.
-
     Attributes:
         gcs_destination (google.cloud.automl_v1beta1.types.GcsDestination):
             The Google Cloud Storage location where the model is to be
@@ -999,14 +991,11 @@ class ModelExportOutputConfig(proto.Message):
     gcs_destination = proto.Field(
         proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
     )
-
     gcr_destination = proto.Field(
         proto.MESSAGE, number=3, oneof="destination", message="GcrDestination",
     )
-
-    model_format = proto.Field(proto.STRING, number=4)
-
-    params = proto.MapField(proto.STRING, proto.STRING, number=2)
+    model_format = proto.Field(proto.STRING, number=4,)
+    params = proto.MapField(proto.STRING, proto.STRING, number=2,)
 
 
 class ExportEvaluatedExamplesOutputConfig(proto.Message):
@@ -1052,7 +1041,6 @@ class ExportEvaluatedExamplesOutputConfig(proto.Message):
 
 class GcsSource(proto.Message):
     r"""The Google Cloud Storage location for the input content.
-
     Attributes:
         input_uris (Sequence[str]):
             Required. Google Cloud Storage URIs to input files, up to
@@ -1061,12 +1049,11 @@ class GcsSource(proto.Message):
             -  Full object path, e.g. gs://bucket/directory/object.csv
     """
 
-    input_uris = proto.RepeatedField(proto.STRING, number=1)
+    input_uris = proto.RepeatedField(proto.STRING, number=1,)
 
 
 class BigQuerySource(proto.Message):
     r"""The BigQuery location for the input content.
-
     Attributes:
         input_uri (str):
             Required. BigQuery URI to a table, up to 2000 characters
@@ -1075,7 +1062,7 @@ class BigQuerySource(proto.Message):
             -  BigQuery path e.g. bq://projectId.bqDatasetId.bqTableId
     """
 
-    input_uri = proto.Field(proto.STRING, number=1)
+    input_uri = proto.Field(proto.STRING, number=1,)
 
 
 class GcsDestination(proto.Message):
@@ -1092,12 +1079,11 @@ class GcsDestination(proto.Message):
                is created if it doesn't exist.
     """
 
-    output_uri_prefix = proto.Field(proto.STRING, number=1)
+    output_uri_prefix = proto.Field(proto.STRING, number=1,)
 
 
 class BigQueryDestination(proto.Message):
     r"""The BigQuery location for the output content.
-
     Attributes:
         output_uri (str):
             Required. BigQuery URI to a project, up to 2000 characters
@@ -1106,12 +1092,11 @@ class BigQueryDestination(proto.Message):
             -  BigQuery path e.g. bq://projectId
     """
 
-    output_uri = proto.Field(proto.STRING, number=1)
+    output_uri = proto.Field(proto.STRING, number=1,)
 
 
 class GcrDestination(proto.Message):
     r"""The GCR location where the image must be pushed to.
-
     Attributes:
         output_uri (str):
             Required. Google Contained Registry URI of the new image, up
@@ -1128,7 +1113,7 @@ class GcrDestination(proto.Message):
             project.
     """
 
-    output_uri = proto.Field(proto.STRING, number=1)
+    output_uri = proto.Field(proto.STRING, number=1,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
