@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.protobuf import duration_pb2 as duration  # type: ignore
+from google.protobuf import duration_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -41,9 +38,12 @@ class TimeSegment(proto.Message):
             start.
     """
 
-    start_time_offset = proto.Field(proto.MESSAGE, number=1, message=duration.Duration,)
-
-    end_time_offset = proto.Field(proto.MESSAGE, number=2, message=duration.Duration,)
+    start_time_offset = proto.Field(
+        proto.MESSAGE, number=1, message=duration_pb2.Duration,
+    )
+    end_time_offset = proto.Field(
+        proto.MESSAGE, number=2, message=duration_pb2.Duration,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
